summaryrefslogtreecommitdiffstats
path: root/plugins/rssfeed/rss/textinput.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
commit1c1403293485f35fd53db45aaa77a01cdd9627e7 (patch)
tree38559cd68cd4f63023fb5f6375def9db3b8b491e /plugins/rssfeed/rss/textinput.h
parent894f94545727610df22c4f73911d62d58266f695 (diff)
downloadktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.tar.gz
ktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.zip
TQt4 port ktorrent
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktorrent@1238733 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'plugins/rssfeed/rss/textinput.h')
-rw-r--r--plugins/rssfeed/rss/textinput.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/plugins/rssfeed/rss/textinput.h b/plugins/rssfeed/rss/textinput.h
index dd13c42..cbf5bdb 100644
--- a/plugins/rssfeed/rss/textinput.h
+++ b/plugins/rssfeed/rss/textinput.h
@@ -15,8 +15,8 @@
class KURL;
-class QDomNode;
-class QString;
+class TQDomNode;
+class TQString;
namespace RSS
{
@@ -43,10 +43,10 @@ namespace RSS
/**
* Constructs a TextInput from a piece of RSS markup.
* @param node A QDomNode which references the DOM leaf to be used
* for constructing the TextInput.
*/
- TextInput(const QDomNode &node);
+ TextInput(const TQDomNode &node);
/**
* Assignment operator.
@@ -79,25 +79,25 @@ namespace RSS
/**
* RSS 0.90 and upwards
* @return The title (often a label to be used for the input field)
* of the text input, or QString::null if no title is available.
*/
- QString title() const;
+ TQString title() const;
/**
* RSS 0.90 and upwards
* @return The description (usually used as a tooltip which appears
* if the mouse hovers above the input field for a short time) of
* the text input, or QString::null if no description is
* available.
*/
- QString description() const;
+ TQString description() const;
/**
* RSS 0.90 and upwards
* @return The name of the text input (what's this for?) of the
* text input, or QString::null, if no name is available.
*/
- QString name() const;
+ TQString name() const;
/**
* RSS 0.90 and upwards
@@ -43,10 +43,10 @@ namespace RSS
/**
* Constructs a TextInput from a piece of RSS markup.
- * @param node A QDomNode which references the DOM leaf to be used
+ * @param node A TQDomNode which references the DOM leaf to be used
* for constructing the TextInput.
*/
@@ -79,25 +79,25 @@ namespace RSS
* RSS 0.90 and upwards
* @return The title (often a label to be used for the input field)
- * of the text input, or QString::null if no title is available.
+ * of the text input, or TQString() if no title is available.
*/
@@ -79,25 +79,25 @@ namespace RSS
* @return The description (usually used as a tooltip which appears
* if the mouse hovers above the input field for a short time) of
- * the text input, or QString::null if no description is
+ * the text input, or TQString() if no description is
* available.
*/
@@ -79,25 +79,25 @@ namespace RSS
* RSS 0.90 and upwards
* @return The name of the text input (what's this for?) of the
- * text input, or QString::null, if no name is available.
+ * text input, or TQString(), if no name is available.
*/